import Button from "@/components/base/Button/index";
import React, { useState } from "react";

interface PaginationProps {
  size: number;
  currentPage: number;
  onChange: (index: number) => void;
}

const Pagination: React.FC<PaginationProps> = ({ size, currentPage, onChange }) => {
  const [isShow, setIsShow] = useState(false);
  const count = 2;

  const handleEllipsisClick = () => {
    setIsShow(!isShow);
  };

  const renderPageButtons = () => {
    const pages = [];

    if (currentPage > 1) {
      pages.push(
        <Button key="prev" size="sm" onClick={() => onChange(currentPage - 1)}>
          Previous
        </Button>
      );
    }

    if (currentPage > 2 && !isShow) {
      pages.push(
        <Button key="1" size="icon" onClick={() => onChange(1)}>
          1
        </Button>,
        <Button key="ellipsis-start" size="icon" onClick={handleEllipsisClick}>
          ...
        </Button>
      );
    }

    const startPage = isShow ? 1 : Math.max(currentPage, 1);
    const endPage = isShow ? size : Math.min(currentPage + count, size);

    for (let i = startPage; i <= endPage; i++) {
      const isPrimary = currentPage === i;
      pages.push(
        <Button key={i} size="icon" isPrimary={isPrimary} onClick={() => onChange(i)}>
          {i}
        </Button>
      );
    }

    if (!isShow && size - currentPage > count+1) {
      pages.push(
        <Button key="ellipsis-end" size="icon" onClick={handleEllipsisClick}>
          ...
        </Button>,
        <Button key={size} size="icon" onClick={() => onChange(size)}>
          {size}
        </Button>
      );
    }

    if (currentPage < size) {
      pages.push(
        <Button key="next" size="sm" onClick={() => onChange(currentPage + 1)}>
          Next
        </Button>
      );
    }
    return pages;
  };

  return <div className="flex gap-2 flex-wrap my-10">{renderPageButtons()}</div>;
};

export default Pagination;
